@@ -17,30 +17,24 @@ typedef struct record_file_table {
 	/* Fill record structuure based on supplied parse info.
 	 * Parser must return STATUS_NODATA when EOF is encountered.
 	 * Parser must handle NULL file stream correctly */
-	int (*parse) (
-		semanage_handle_t* handle,
-		parse_info_t* info, 
-		record_t* record);
+	int (*parse) (semanage_handle_t * handle,
+		      parse_info_t * info, record_t * record);
 
 	/* Print record to stream */
-	int (*print) (
-		semanage_handle_t* handle,
-		record_t* record, 
-		FILE* str);
+	int (*print) (semanage_handle_t * handle,
+		      record_t * record, FILE * str);
 
 } record_file_table_t;
 
 /* FILE - initialization */
-extern int dbase_file_init(
-	semanage_handle_t* handle,
-	const char* suffix,
-	record_table_t* rtable,
-	record_file_table_t* rftable,
-	dbase_file_t** dbase);
+extern int dbase_file_init(semanage_handle_t * handle,
+			   const char *suffix,
+			   record_table_t * rtable,
+			   record_file_table_t * rftable,
+			   dbase_file_t ** dbase);
 
 /* FILE - release */
-extern void dbase_file_release(
-	dbase_file_t* dbase);
+extern void dbase_file_release(dbase_file_t * dbase);
 
 /* FILE - method table implementation */
 extern dbase_table_t SEMANAGE_FILE_DTABLE;
