@@ -20,18 +20,17 @@ typedef struct dbase_file dbase_t;
 #include "parse_utils.h"
 #include "debug.h"
 
-static int port_print(
-	semanage_handle_t* handle,
-	semanage_port_t* port, 
-	FILE* str) {
+static int port_print(semanage_handle_t * handle,
+		      semanage_port_t * port, FILE * str)
+{
 
-	char* con_str = NULL;
+	char *con_str = NULL;
 
 	int low = semanage_port_get_low(port);
 	int high = semanage_port_get_high(port);
 	int proto = semanage_port_get_proto(port);
-	const char* proto_str = semanage_port_get_proto_str(proto);
-	semanage_context_t* con = semanage_port_get_con(port);
+	const char *proto_str = semanage_port_get_proto_str(proto);
+	semanage_context_t *con = semanage_port_get_con(port);
 
 	if (fprintf(str, "portcon %s ", proto_str) < 0)
 		goto err;
@@ -52,21 +51,20 @@ static int port_print(
 	free(con_str);
 	return STATUS_SUCCESS;
 
-	err:
-	ERR(handle, "could not print port range %u - %u (%s) to stream", 
-		low, high, proto_str);
+      err:
+	ERR(handle, "could not print port range %u - %u (%s) to stream",
+	    low, high, proto_str);
 	free(con_str);
 	return STATUS_ERR;
 }
 
-static int port_parse(
-	semanage_handle_t* handle,
-	parse_info_t* info, 
-	semanage_port_t* port) {
+static int port_parse(semanage_handle_t * handle,
+		      parse_info_t * info, semanage_port_t * port)
+{
 
 	int low, high;
-	char* str = NULL;
-	semanage_context_t* con = NULL;
+	char *str = NULL;
+	semanage_context_t *con = NULL;
 
 	if (parse_skip_space(handle, info) < 0)
 		goto err;
@@ -88,7 +86,7 @@ static int port_parse(
 		semanage_port_set_proto(port, SEMANAGE_PROTO_UDP);
 	else {
 		ERR(handle, "invalid protocol \"%s\" (%s: %u):\n%s", str,
-				info->filename, info->lineno, info->orig_line);
+		    info->filename, info->lineno, info->orig_line);
 		goto err;
 	}
 	free(str);
@@ -112,28 +110,27 @@ static int port_parse(
 	if (parse_optional_ch(info, '-') != STATUS_NODATA) {
 
 		if (parse_skip_space(handle, info) < 0)
-			goto err;	
+			goto err;
 		if (parse_fetch_int(handle, info, &high, ' ') < 0)
 			goto err;
 		if (parse_assert_space(handle, info) < 0)
 			goto err;
 		semanage_port_set_range(port, low, high);
-	}
-	else 
+	} else
 		semanage_port_set_port(port, low);
 
-        /* Port context */
+	/* Port context */
 	if (parse_fetch_string(handle, info, &str, ' ') < 0)
 		goto err;
 	if (semanage_context_from_string(handle, str, &con) < 0) {
 		ERR(handle, "invalid security context \"%s\" (%s: %u)\n%s",
-			str, info->filename, info->lineno, info->orig_line);
+		    str, info->filename, info->lineno, info->orig_line);
 		goto err;
 	}
 	if (con == NULL) {
 		ERR(handle, "<<none>> context is not valid "
-			"for ports (%s: %u):\n%s", info->filename, 
-			info->lineno, info->orig_line);
+		    "for ports (%s: %u):\n%s", info->filename,
+		    info->lineno, info->orig_line);
 		goto err;
 	}
 	free(str);
@@ -148,11 +145,11 @@ static int port_parse(
 	semanage_context_free(con);
 	return STATUS_SUCCESS;
 
-	last:
+      last:
 	parse_dispose_line(info);
 	return STATUS_NODATA;
 
-	err:
+      err:
 	ERR(handle, "could not parse port record");
 	free(str);
 	semanage_context_free(con);
@@ -162,29 +159,26 @@ static int port_parse(
 
 /* PORT RECORD: FILE extension: method table */
 record_file_table_t SEMANAGE_PORT_FILE_RTABLE = {
-	.parse       = port_parse,
-	.print       = port_print,
+	.parse = port_parse,
+	.print = port_print,
 };
 
-int port_file_dbase_init(
-	semanage_handle_t* handle,
-	const char* fname,
-	dbase_config_t* dconfig) {
+int port_file_dbase_init(semanage_handle_t * handle,
+			 const char *fname, dbase_config_t * dconfig)
+{
 
-	if (dbase_file_init(
-		handle, 
-		fname,
-		&SEMANAGE_PORT_RTABLE,
-		&SEMANAGE_PORT_FILE_RTABLE,
-		&dconfig->dbase) < 0)
+	if (dbase_file_init(handle,
+			    fname,
+			    &SEMANAGE_PORT_RTABLE,
+			    &SEMANAGE_PORT_FILE_RTABLE, &dconfig->dbase) < 0)
 		return STATUS_ERR;
 
 	dconfig->dtable = &SEMANAGE_FILE_DTABLE;
 	return STATUS_SUCCESS;
 }
 
-void port_file_dbase_release(
-	dbase_config_t* dconfig) {
+void port_file_dbase_release(dbase_config_t * dconfig)
+{
 
 	dbase_file_release(dconfig->dbase);
 }
